diff src/ex_getln.c @ 12960:004bc78c88e6 v8.0.1356

patch 8.0.1356: using simalt in a GUIEnter autocommand inserts characters commit https://github.com/vim/vim/commit/c5aa55db7e5bc791f99fb15b0f4be0d5dd166f62 Author: Bram Moolenaar <Bram@vim.org> Date: Tue Nov 28 20:47:40 2017 +0100 patch 8.0.1356: using simalt in a GUIEnter autocommand inserts characters Problem: Using simalt in a GUIEnter autocommand inserts strange characters. (Chih-Long Chang) Solution: Ignore K_NOP in Insert mode. (closes #2379)
author Christian Brabandt <cb@256bit.org>
date Tue, 28 Nov 2017 21:00:07 +0100
parents 85a601f985ab
children 89e191a2a8a7
line wrap: on
line diff
--- a/src/ex_getln.c
+++ b/src/ex_getln.c
@@ -417,12 +417,12 @@ getcmdline(
 
 	cursorcmd();		/* set the cursor on the right spot */
 
 	/* Get a character.  Ignore K_IGNORE, it should not do anything, such
 	 * as stop completion. */
 	do
 	{
 	    c = safe_vgetc();
-	} while (c == K_IGNORE);
+	} while (c == K_IGNORE || c == K_NOP);
 
 	if (KeyTyped)
 	{
@@ -417,12 +417,12 @@ getcmdline(
 	cursorcmd();		/* set the cursor on the right spot */
 
-	/* Get a character.  Ignore K_IGNORE, it should not do anything, such
-	 * as stop completion. */
+	/* Get a character.  Ignore K_IGNORE and K_NOP, they should not do
+	 * anything, such as stop completion. */
 	do
 	{